@@ -56,21 +56,18 @@ main(int argc, char *argv[])
         int fd;
 	int ret;
 	char *table = "filter";
-	iptc_handle_t handle = NULL;
+	struct iptc_handle *handle = NULL;
 
-	program_name = "iptables";
-	//program_version = IPTABLES_VERSION;
-	program_version = XTABLES_VERSION;
+	iptables_globals.program_name = "iptables";
+	//iptables_globals.program_version = XTABLES_VERSION;
 
-	lib_dir = getenv("XTABLES_LIBDIR");
-	if (lib_dir == NULL) {
-		lib_dir = getenv("IPTABLES_LIB_DIR");
-		if (lib_dir != NULL)
-			fprintf(stderr, "IPTABLES_LIB_DIR is deprecated\n");
+	ret = xtables_init_all(&iptables_globals, NFPROTO_IPV4);
+	if (ret < 0) {
+		fprintf(stderr, "%s/%s Failed to initialize xtables\n",
+				iptables_globals.program_name,
+				iptables_globals.program_version);
+				exit(1);
 	}
-	if (lib_dir == NULL)
-		lib_dir = XTABLES_LIBDIR;
-
 #ifdef NO_SHARED_LIBS
 	init_extensions();
 #endif
@@ -85,11 +82,12 @@ main(int argc, char *argv[])
 
 	ret = do_command(argc, argv, &table, &handle);
 	if (ret) {
-		ret = iptc_commit(&handle);
+		ret = iptc_commit(handle);
 		if (errno == EAGAIN) {
 			fprintf(stderr, "iptc_commit: %s\n", strerror(errno));
 			exit(RESOURCE_PROBLEM);
 		}
+		iptc_free(handle);
 	}
 
 	flock(fd, LOCK_UN);
